# coding: utf-8

init_blog_code = '''# coding: utf-8
from flask import Flask, render_template, url_for
from flask_flatpages import FlatPages
from flask_frozen import Freezer
from config import config
import shutil
import sys
import os

reload(sys)
sys.setdefaultencoding('utf-8')

app = Flask(__name__)
app.config.from_object(config['default'])
pages = FlatPages(app)
freezer = Freezer(app)

@app.route('/index/')
def index():
    posts = (p for p in pages if 'date' in p.meta)
    latests = sorted(posts, reverse=True, key=lambda x:x.meta['date'])
    tags = []
    archive = []
    for p in pages:
        tags = [tag for tag in p.meta.get('tags') if tag not in tags]
        year = str(p.meta.get('date'))[:-3]
        if year not in archive:
            archive.append(year)
    return render_template(
        'index.html', latests=latests,
        tags=tags,
        archive=archive,
        blog_title=app.config['BLOG_TITLE'],
        blog_url=app.config['BLOG_URL'],
        blog_description=app.config['BLOG_DESCRIPTION'],
        blog_keywords=app.config['BLOG_KEYWORDS']
    )

@app.route('/<path:path>/')
def page(path):
    tags = []
    archive = []
    for p in pages:
        tags = [tag for tag in p.meta.get('tags') if tag not in tags]
        year = str(p.meta.get('date'))[:-3]
        if year not in archive:
            archive.append(year)
    post = pages.get_or_404(path)
    return render_template('post.html',
        post=post,
        tags=tags,
        archive=archive
    )

@app.route('/tags/<string:tag>/')
def tags(tag):
    """获取相应tag下的所有博文"""
    posts = [p for p in pages if tag in p.meta.get('tags', [])]
    posts_num = len(posts)
    return render_template('tags.html',
        tag = tag,
        posts = posts,
        posts_num = posts_num
    )

@app.route('/archive/<string:year>/')
def archive(year):
    """博文归档"""
    posts = [p for p in pages if year in str(p.meta.get('date'))[:-3]]
    posts_num = len(posts)
    return render_template('archive.html',
        posts = posts,
        year = year,
        posts_num = posts_num
    )

def upload():
    os.chdir(build_path)
    os.popen('git add .')
    os.popen('git commit -m "cat blog update"')
    os.popen('git push -u %s master' % app.config['GIT_URL'])

if __name__ == '__main__':
    if len(sys.argv) > 1 and sys.argv[1] == "build":
        freezer.freeze()
    elif len(sys.argv) > 1 and sys.argv[1] == "upload":
        upload()
    else:
        app.run(debug=True)
'''



# coding: utf-8

init_hello_code = '''title: hello from cat
date: 2016-01-23
tags: ['hello', 'cat']
img: http://7xj431.com1.z0.glb.clouddn.com/catg

cat
===
python家的静态博客生成器<br/>
![cat](http://7xj431.com1.z0.glb.clouddn.com/haha.gif)

### 安装(pip install catg)

    $ pip install catg

### 生成blog

    $ ca init

(注: 以下所有命令需在<code>blog/</code>下运行)
### 添加新博文

    $ ca new post
    \_title:
    \_date[YYYY-MM-DD]:
    \_tags[tag1 tag2]:

### 预览博客

    $ ca runserver
    访问 http://127.0.0.1:5000 即可预览博客

### 部署博客
要求使用github pages进行部署
#### 1. 注册一个github账号
#### 2. 创建一个仓库, 仓库名: <code>github用户名.github.io</code>
#### 3. 配置<code>config.py</code>的<code>GIT_URL</code>为创建仓库的git地址(https协议)
#### 4. 本地运行<code>$ ca upload</code>部署博客
#### 5. 访问 http://github用户名.github.io 即可看到你的博客(可能需要等一会)

### 默认主题 cat
![cat](http://7xj431.com1.z0.glb.clouddn.com/cattheme)

### 配置博客
采用**python类**的语法进行配置(都是程序员嘛,就像nginx配置一样😄 ), 示例:

    """
    默认配置
    --> DEBUG: debug模式
    --> FLATPAGES_AUTO_RELOAD
    --> FLATPAGES_EXTENSION ==> flask-flatpages 配置
    """
    class Config:
        DEBUG = True
        FLATPAGES_AUTO_RELOAD = DEBUG
        FLATPAGES_EXTENSION = '.md'

    """
    个人配置
    --> BLOG_TITLE: 博客标题
    --> BLOG_URL: 博客URL地址
    --> BLOG_DESCRIPTION: 博客描述
    --> BLOG_KEYWORDS: 这个博客的关键字
    --> BLOG_THEME: 博客主题
    --> GIT_URL: 部署至github仓库的url
    """
    class MyConfig(Config):
        BLOG_TITLE = "cat^0^python家的静态博客生成器"
        BLOG_URL = "http://127.0.0.1:5000"
        BLOG_DESCRIPTION = "python static blog generator"
        BLOG_KEYWORDS = "python static blog cat"
        GIT_URL = "https://github.com/neo1218/neo1218.github.io.git"

    """有效配置名称"""
    config = {
        'default': MyConfig
    }

## 编写主题
使用 html(jinja2模版), css, js 编写主题, 可以编写的页面如下表: <br/>
![table](http://7xj431.com1.z0.glb.clouddn.com/table)

## 更换主题

0. 查看[cat主题收录列表](https://github.com/neo1218/cat/tree/master/cat/theme),找到自己喜爱的主题
1. clone github上相应主题到theme目录下
2. 运行<code>ca upgrade theme_name</code>更新主题(theme_name为theme目录下相应主题的目录名)
'''
